# 1. Introduction
> Simple calculator for solving problems related to discrete mathmatics, such as combinations, probabilities, truth-tables, and more.
# 2. How to Install
> - pip install discrete-math-helper
# 3. How to Run
> - from discrete_help_helper import calc
> - calc = Calculator()
> - #Combination Example: calc.combination(6, 2)
> - #Truth Table Example: calc.truthtable("p and q")
# 4. Available Arguments
> - Combinations: calc.combination(n,r)
> - Permutations: calc.permutation(n,r)
> - Truth Table: calc.truthtable("statement containing variables: p, q")
> - Bayes' Probability: calc.bayes(P(T|A), P(A), P(T))
> - Big O Calculator: calc.bigo(a,b,d)
# 5. Creater Contact Information
> - Email: dokkuh@umich.edu
> - Phone: (479) 544-2885
# 6. Contributors
> - Zalan Shah: zalans@umich.edu
